@@ -145,57 +145,3 @@ HetSNmleVCov <- function(nk,p,k,Config,SigmaE,HomSNvcov,grpnames)
 
   mlevcov
 }
-
-vcovCind <- function(Conf,p)
-{
-  if (!is.element(Conf,2:5)) {
-    stop("Wrong value for Conf element\n")
-  }
-  q <- p/2
-  mind <- NULL
-  cind <- 0
-  if (Conf==2)  {
-    for (i in 1:q) {
-      mind <- c(mind,cind+1:(q-i+1),cind+q+1)
-      cind <- cind + q + (q-i+1)
-    }
-    for (i in 1:q) {
-      mind <- c(mind,cind+1:(q-i+1))
-      cind <- cind + (q-i+1)
-    }
-  }  
-  if (Conf==3)  {
-    for (i in 1:q) {
-      mind <- c(mind,cind+1,cind+q+1)
-      cind <- cind + q + (q-i+1)
-    }
-    for (i in 1:q) {
-      mind <- c(mind,cind+1)
-      cind <- cind + (q-i+1)
-    }
-  }  
-  if (Conf==4)
-  {
-    for (i in 1:q) {
-      mind <- c(mind,cind+1:(q-i+1))
-      cind <- cind + q + (q-i+1)
-    }
-    for (i in 1:q) {
-      mind <- c(mind,cind+1:(q-i+1))
-      cind <- cind + (q-i+1)
-    }
-  }
-  if (Conf==5) 
-  {
-    for (i in 1:q) {
-      mind <- c(mind,cind+1)
-      cind <- cind + q + (q-i+1)
-    }
-    for (i in 1:q) {
-      mind <- c(mind,cind+1)
-      cind <- cind + (q-i+1)
-    }
-  }
-  mind  #  return(mind)
-}
-
